Archive

Struct Archive 

pub struct Archive { /* private fields */ }
Parsed Human Readable Archive data.

Implementations

Source

impl Archive

pub fn load(file: &Path) -> Result<Archive, FileError>

Load hrx data from a file system path.

Errors

Returns a FileError::Io if the path can’t be read or a FileError::Data if the contents isn’t proper hrx.

pub fn parse(data: &str) -> Result<Archive, Error>

Parse hrx data from an in-memory buffer.

Errors

Returns an error if data is not proper hrx contents.

pub fn names(&self) -> Vec<&str>

Get a vec of the file names in the archive.

pub fn get(&self, name: &str) -> Option<&str>

Get the contents of a file in the archive.

pub fn entries(&self) -> impl Iterator<Item = (&str, &str)>

Iterate over (name, content) pairs for the files in the archive.